@@ -40,3 +40,7 @@ NULL
 #' @name surveyvoi
 #' @docType package
 NULL
+
+# ensure package checks pass
+#' @importFrom utils zip
+NULL
